@@ -38,8 +38,6 @@
 #include "simutil.h"
 #include "storage.h"
 
-#define CBS_MANAGER_INTERFACE "org.ofono.CbsManager"
-
 #define SETTINGS_STORE "cbs"
 #define SETTINGS_GROUP "Settings"
 
@@ -130,7 +128,7 @@ static void cbs_dispatch_emergency(struct ofono_cbs *cbs, const char *message,
 		return;
 	};
 
-	signal = dbus_message_new_signal(path, CBS_MANAGER_INTERFACE,
+	signal = dbus_message_new_signal(path, OFONO_CBS_MANAGER_INTERFACE,
 						"EmergencyBroadcast");
 
 	if (!signal)
@@ -164,7 +162,7 @@ static void cbs_dispatch_text(struct ofono_cbs *cbs, enum sms_class cls,
 	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path = __ofono_atom_get_path(cbs->atom);
 
-	g_dbus_emit_signal(conn, path, CBS_MANAGER_INTERFACE,
+	g_dbus_emit_signal(conn, path, OFONO_CBS_MANAGER_INTERFACE,
 				"IncomingBroadcast",
 				DBUS_TYPE_STRING, &message,
 				DBUS_TYPE_UINT16, &channel,
@@ -331,7 +329,7 @@ static void cbs_set_topics_cb(const struct ofono_error *error, void *data)
 		g_slist_free(cbs->new_topics);
 		cbs->new_topics = NULL;
 
-		ofono_debug("Setting Cell Broadcast topics failed");
+		DBG("Setting Cell Broadcast topics failed");
 		__ofono_dbus_pending_reply(&cbs->pending,
 					__ofono_error_failed(cbs->pending));
 		return;
@@ -347,7 +345,7 @@ static void cbs_set_topics_cb(const struct ofono_error *error, void *data)
 
 	topics = cbs_topic_ranges_to_string(cbs->topics);
 	ofono_dbus_signal_property_changed(conn, path,
-						CBS_MANAGER_INTERFACE,
+						OFONO_CBS_MANAGER_INTERFACE,
 						"Topics",
 						DBUS_TYPE_STRING, &topics);
 
@@ -418,7 +416,7 @@ static void cbs_set_powered_cb(const struct ofono_error *error, void *data)
 	}
 
 	ofono_dbus_signal_property_changed(conn, path,
-						CBS_MANAGER_INTERFACE,
+						OFONO_CBS_MANAGER_INTERFACE,
 						"Powered",
 						DBUS_TYPE_BOOLEAN,
 						&cbs->powered);
@@ -467,7 +465,7 @@ done:
 	}
 
 	ofono_dbus_signal_property_changed(conn, path,
-						CBS_MANAGER_INTERFACE,
+						OFONO_CBS_MANAGER_INTERFACE,
 						"Powered",
 						DBUS_TYPE_BOOLEAN,
 						&cbs->powered);
@@ -569,8 +567,8 @@ static void cbs_unregister(struct ofono_atom *atom)
 	struct ofono_modem *modem = __ofono_atom_get_modem(atom);
 	const char *path = __ofono_atom_get_path(atom);
 
-	g_dbus_unregister_interface(conn, path, CBS_MANAGER_INTERFACE);
-	ofono_modem_remove_interface(modem, CBS_MANAGER_INTERFACE);
+	g_dbus_unregister_interface(conn, path, OFONO_CBS_MANAGER_INTERFACE);
+	ofono_modem_remove_interface(modem, OFONO_CBS_MANAGER_INTERFACE);
 
 	if (cbs->topics) {
 		g_slist_foreach(cbs->topics, (GFunc)g_free, NULL);
@@ -770,7 +768,7 @@ static void sim_cbmi_read_cb(int ok, int length, int record,
 		return;
 
 	str = cbs_topic_ranges_to_string(cbs->efcbmi_contents);
-	ofono_debug("Got cbmi: %s", str);
+	DBG("Got cbmi: %s", str);
 	g_free(str);
 }
 
@@ -817,7 +815,7 @@ static void sim_cbmir_read_cb(int ok, int length, int record,
 		return;
 
 	str = cbs_topic_ranges_to_string(cbs->efcbmir_contents);
-	ofono_debug("Got cbmir: %s", str);
+	DBG("Got cbmir: %s", str);
 	g_free(str);
 }
 
@@ -860,7 +858,7 @@ static void sim_cbmid_read_cb(int ok, int length, int record,
 	cbs->efcbmid_contents = g_slist_reverse(contents);
 
 	str = cbs_topic_ranges_to_string(cbs->efcbmid_contents);
-	ofono_debug("Got cbmid: %s", str);
+	DBG("Got cbmid: %s", str);
 	g_free(str);
 
 done:
@@ -872,7 +870,7 @@ static void cbs_got_imsi(struct ofono_cbs *cbs)
 	const char *imsi = ofono_sim_get_imsi(cbs->sim);
 	char *topics_str;
 
-	ofono_debug("Got IMSI: %s", imsi);
+	DBG("Got IMSI: %s", imsi);
 
 	cbs->settings = storage_open(imsi, SETTINGS_STORE);
 	if (cbs->settings == NULL)
@@ -1032,16 +1030,16 @@ void ofono_cbs_register(struct ofono_cbs *cbs)
 	struct ofono_atom *netreg_atom;
 
 	if (!g_dbus_register_interface(conn, path,
-					CBS_MANAGER_INTERFACE,
+					OFONO_CBS_MANAGER_INTERFACE,
 					cbs_manager_methods,
 					cbs_manager_signals,
 					NULL, cbs, NULL)) {
 		ofono_error("Could not create %s interface",
-				CBS_MANAGER_INTERFACE);
+				OFONO_CBS_MANAGER_INTERFACE);
 		return;
 	}
 
-	ofono_modem_add_interface(modem, CBS_MANAGER_INTERFACE);
+	ofono_modem_add_interface(modem, OFONO_CBS_MANAGER_INTERFACE);
 
 	sim_atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_SIM);
 
