@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -39,8 +39,6 @@
 
 #define uninitialized_var(x) x = x
 
-#define SMS_MANAGER_INTERFACE "org.ofono.SmsManager"
-
 #define SMS_MANAGER_FLAG_CACHED 0x1
 
 #define SETTINGS_STORE "sms"
@@ -105,7 +103,7 @@ static void set_sca(struct ofono_sms *sms,
 	value = phone_number_to_string(&sms->sca);
 
 	ofono_dbus_signal_property_changed(conn, path,
-						SMS_MANAGER_INTERFACE,
+						OFONO_SMS_MANAGER_INTERFACE,
 						"ServiceCenterAddress",
 						DBUS_TYPE_STRING, &value);
 }
@@ -206,7 +204,7 @@ static void sca_set_callback(const struct ofono_error *error, void *data)
 	struct ofono_sms *sms = data;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		ofono_debug("Setting SCA failed");
+		DBG("Setting SCA failed");
 		__ofono_dbus_pending_reply(&sms->pending,
 					__ofono_error_failed(sms->pending));
 		return;
@@ -272,20 +270,20 @@ static void tx_finished(const struct ofono_error *error, int mr, void *data)
 	struct ofono_modem *modem = __ofono_atom_get_modem(sms->atom);
 	struct tx_queue_entry *entry = g_queue_peek_head(sms->txq);
 
-	ofono_debug("tx_finished");
+	DBG("tx_finished");
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
 		entry->retry += 1;
 
 		if (entry->retry != TXQ_MAX_RETRIES) {
-			ofono_debug("Sending failed, retry in %d secs",
+			DBG("Sending failed, retry in %d secs",
 					entry->retry * 5);
 			sms->tx_source = g_timeout_add_seconds(entry->retry * 5,
 								tx_next, sms);
 			return;
 		}
 
-		ofono_debug("Max retries reached, giving up");
+		DBG("Max retries reached, giving up");
 
 		entry = g_queue_pop_head(sms->txq);
 		__ofono_dbus_pending_reply(&entry->msg,
@@ -299,7 +297,7 @@ static void tx_finished(const struct ofono_error *error, int mr, void *data)
 		g_free(entry);
 
 		if (g_queue_peek_head(sms->txq)) {
-			ofono_debug("Previous send failed, scheduling next");
+			DBG("Previous send failed, scheduling next");
 			sms->tx_source = g_timeout_add(0, tx_next, sms);
 		}
 
@@ -325,7 +323,7 @@ static void tx_finished(const struct ofono_error *error, int mr, void *data)
 	g_free(entry);
 
 	if (g_queue_peek_head(sms->txq)) {
-		ofono_debug("Scheduling next");
+		DBG("Scheduling next");
 		sms->tx_source = g_timeout_add(0, tx_next, sms);
 	}
 }
@@ -341,7 +339,7 @@ static gboolean tx_next(gpointer user_data)
 
 	error.type = OFONO_ERROR_TYPE_NO_ERROR;
 
-	ofono_debug("tx_next: %p", entry);
+	DBG("tx_next: %p", entry);
 
 	sms->tx_source = 0;
 
@@ -388,12 +386,12 @@ static struct tx_queue_entry *create_tx_queue_entry(GSList *msg_list)
 	entry->pdus = g_new0(struct pending_pdu, entry->num_pdus);
 
 	for (l = msg_list; l; l = l->next) {
-		struct pending_pdu *pdu = &entry->pdus[i];
+		struct pending_pdu *pdu = &entry->pdus[i++];
 		struct sms *s = l->data;
 
 		sms_encode(s, &pdu->pdu_len, &pdu->tpdu_len, pdu->pdu);
 
-		ofono_debug("pdu_len: %d, tpdu_len: %d",
+		DBG("pdu_len: %d, tpdu_len: %d",
 				pdu->pdu_len, pdu->tpdu_len);
 	}
 
@@ -424,7 +422,7 @@ static DBusMessage *sms_send_message(DBusConnection *conn, DBusMessage *msg,
 	if (!msg_list)
 		return __ofono_error_invalid_format(msg);
 
-	ofono_debug("ref: %d, offset: %d", sms->ref, ref_offset);
+	DBG("ref: %d, offset: %d", sms->ref, ref_offset);
 
 	set_ref_and_to(msg_list, sms->ref, ref_offset, to);
 	entry = create_tx_queue_entry(msg_list);
@@ -474,9 +472,9 @@ static GDBusSignalTable sms_manager_signals[] = {
 static void dispatch_app_datagram(struct ofono_sms *sms, int dst, int src,
 					unsigned char *buf, long len)
 {
-	ofono_debug("Got app datagram for dst port: %d, src port: %d",
+	DBG("Got app datagram for dst port: %d, src port: %d",
 			dst, src);
-	ofono_debug("Contents-Len: %ld", len);
+	DBG("Contents-Len: %ld", len);
 }
 
 static void dispatch_text_message(struct ofono_sms *sms,
@@ -506,7 +504,7 @@ static void dispatch_text_message(struct ofono_sms *sms,
 	else
 		signal_name = "IncomingMessage";
 
-	signal = dbus_message_new_signal(path, SMS_MANAGER_INTERFACE,
+	signal = dbus_message_new_signal(path, OFONO_SMS_MANAGER_INTERFACE,
 						signal_name);
 
 	if (!signal)
@@ -601,10 +599,14 @@ static void sms_dispatch(struct ofono_sms *sms, GSList *sms_list)
 			return;
 		}
 
-		if (sms_extract_app_port(s, &cdst, &csrc, &is_8bit) &&
-				(l == sms_list)) {
-			srcport = is_8bit ? csrc : (csrc << 8);
-			dstport = is_8bit ? cdst : (cdst << 8);
+		if (sms_extract_app_port(s, &cdst, &csrc, &is_8bit)) {
+			csrc = is_8bit ? csrc : (csrc << 8);
+			cdst = is_8bit ? cdst : (cdst << 8);
+
+			if (l == sms_list) {
+				srcport = csrc;
+				dstport = cdst;
+			}
 		}
 
 		if (srcport != csrc || dstport != cdst) {
@@ -710,7 +712,7 @@ void ofono_sms_deliver_notify(struct ofono_sms *sms, unsigned char *pdu,
 	}
 
 	if (s.deliver.pid == SMS_PID_TYPE_SM_TYPE_0) {
-		ofono_debug("Explicitly ignoring type 0 SMS");
+		DBG("Explicitly ignoring type 0 SMS");
 		return;
 	}
 
@@ -836,12 +838,19 @@ void ofono_sms_driver_unregister(const struct ofono_sms_driver *d)
 
 static void sms_unregister(struct ofono_atom *atom)
 {
+	struct ofono_sms *sms = __ofono_atom_get_data(atom);
 	DBusConnection *conn = ofono_dbus_get_connection();
 	struct ofono_modem *modem = __ofono_atom_get_modem(atom);
 	const char *path = __ofono_atom_get_path(atom);
 
-	g_dbus_unregister_interface(conn, path, SMS_MANAGER_INTERFACE);
-	ofono_modem_remove_interface(modem, SMS_MANAGER_INTERFACE);
+	g_dbus_unregister_interface(conn, path, OFONO_SMS_MANAGER_INTERFACE);
+	ofono_modem_remove_interface(modem, OFONO_SMS_MANAGER_INTERFACE);
+
+	if (sms->mw_watch) {
+		__ofono_modem_remove_atom_watch(modem, sms->mw_watch);
+		sms->mw_watch = 0;
+		sms->mw = NULL;
+	}
 }
 
 static void sms_remove(struct ofono_atom *atom)
@@ -967,16 +976,16 @@ void ofono_sms_register(struct ofono_sms *sms)
 	struct ofono_atom *sim_atom;
 
 	if (!g_dbus_register_interface(conn, path,
-					SMS_MANAGER_INTERFACE,
+					OFONO_SMS_MANAGER_INTERFACE,
 					sms_manager_methods,
 					sms_manager_signals,
 					NULL, sms, NULL)) {
 		ofono_error("Could not create %s interface",
-				SMS_MANAGER_INTERFACE);
+				OFONO_SMS_MANAGER_INTERFACE);
 		return;
 	}
 
-	ofono_modem_add_interface(modem, SMS_MANAGER_INTERFACE);
+	ofono_modem_add_interface(modem, OFONO_SMS_MANAGER_INTERFACE);
 
 	sms->mw_watch = __ofono_modem_add_atom_watch(modem,
 					OFONO_ATOM_TYPE_MESSAGE_WAITING,
@@ -1002,8 +1011,9 @@ void ofono_sms_register(struct ofono_sms *sms)
 		sms->assembly = sms_assembly_new(imsi);
 
 		sms_load_settings(sms, imsi);
-	} else
+	} else {
 		sms->assembly = sms_assembly_new(NULL);
+	}
 
 	__ofono_atom_register(sms->atom, sms_unregister);
 }
