@@ -2099,7 +2099,7 @@ char *sms_decode_text(GSList *sms_list)
 {
 	GSList *l;
 	GString *str;
-	const struct sms *sms = sms_list->data;
+	const struct sms *sms;
 	int guess_size = g_slist_length(sms_list);
 	char *utf8;
 
@@ -2808,6 +2808,8 @@ gboolean cbs_dcs_decode(guint8 dcs, gboolean *udhi, enum sms_class *cls,
 			ch = (enum sms_charset)((dcs & 0x0c) >> 2);
 		else
 			return FALSE;
+
+		break;
 	case 9:
 		udh = TRUE;
 		cl = (enum sms_class)(dcs & 0x03);
@@ -3028,7 +3030,7 @@ gboolean iso639_2_from_language(enum cbs_language lang, char *iso639)
 char *cbs_decode_text(GSList *cbs_list, char *iso639_lang)
 {
 	GSList *l;
-	const struct cbs *cbs = cbs_list->data;
+	const struct cbs *cbs;
 	enum sms_charset uninitialized_var(charset);
 	enum cbs_language lang;
 	gboolean uninitialized_var(iso639);
@@ -3160,7 +3162,7 @@ char *cbs_decode_text(GSList *cbs_list, char *iso639_lang)
 			}
 
 			while (i < max_offset) {
-				if (ud[i] == 0x00 && ud[i] == '\r')
+				if (ud[i] == 0x00 && ud[i+1] == '\r')
 					break;
 
 				buf[bufsize] = ud[i];
